@@ -3,7 +3,6 @@ import logging
 import re
 from enum import Enum
 
-import util.sql_format as sql_format
 from db_hammer import DB_TYPE_MYSQL
 from db_hammer.csv import start as csv_start
 from db_hammer.entity_util import update_sql, insert_sql, delete_sql, entity_list, where_entity, where_like_entity, \
@@ -49,7 +48,7 @@ class BaseConnection(object):
 
         count_sql = "select COUNT(0) from ( %s ) temp_count" % sql
         count_sql, params = self.sql_params(count_sql, params)
-        self.log.debug("执行SQL:" + sql_format.format(count_sql))
+        self.log.debug("执行SQL:" + count_sql)
         self.log.debug("参数:" + str(params))
         self.cursor.execute(count_sql, params)
         data = self.cursor.fetchone()
@@ -102,7 +101,7 @@ class BaseConnection(object):
         start = page_size * (page_start - 1)
         end = page_size * (page_end - page_start)
         page_sql = """SELECT * FROM ( %s ) temp_page LIMIT %d,%d """ % (sql, start, end)
-        self.log.debug("执行SQL:" + page_sql_format.format(_sql))
+        self.log.debug("执行SQL:" + page_sql)
         page_sql, params = self.sql_params(page_sql, params)
         self.log.debug("参数:" + str(params))
         self.cursor.execute(page_sql, params)
@@ -138,7 +137,7 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("执行SQL:" + sql_format.format(sql))
+        self.log.debug("执行SQL:" + sql)
         _sql, params = self.sql_params(sql, params)
         self.cursor.execute(_sql, params)
         data = self.cursor.fetchone()
@@ -152,7 +151,7 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("执行SQL:" + sql_format.format(sql))
+        self.log.debug("执行SQL:" + sql)
         self.log.debug("参数:" + str(params))
         _sql, params = self.sql_params(sql, params)
         self.cursor.execute(_sql, params)
@@ -167,7 +166,7 @@ class BaseConnection(object):
         :param sql:
         :return:
         """
-        self.log.debug("执行SQL:" + sql_format.format(sql))
+        self.log.debug("执行SQL:" + sql)
         self.log.debug("参数:" + str(params))
         _sql, params = self.sql_params(sql, params)
         self.cursor.execute(_sql, params)
@@ -211,7 +210,7 @@ class BaseConnection(object):
         :return:
         """
         _sql, params = self.sql_params(sql, params)
-        self.log.debug("执行SQL:" + sql_format.format(_sql))
+        self.log.debug("执行SQL:" + _sql)
         self.log.debug("参数:" + str(params))
         if params is None:
             self.cursor.execute(_sql)
