@@ -1,3 +1,4 @@
+from db_hammer import DB_TYPE_MSSQL
 from db_hammer.base import BaseConnection
 
 try:
@@ -18,6 +19,7 @@ except ImportError:
 # pip install pymssql
 class MsSQLConnection(BaseConnection):
     def __init__(self, **kwargs):
+        self.db_type = DB_TYPE_MSSQL
         if kwargs.get("host", None) is None:
             raise Exception("host")
         if kwargs.get("user", None) is None:
