@@ -1,20 +1,16 @@
-from typing import Any, List
 
-from pydantic import BaseModel
-
-
-class PageInput(BaseModel):
+class PageInput:
     sort_by: str = ""
     descending: bool = False
     page_size: int = 30
     page_start: int = 1
 
 
-class PageOutput(BaseModel):
+class PageOutput:
     rows_number: int = 0
     sort_by: str = ""
     descending: bool = False
     page_size: int = 30
     page_start: int = 1
     page_number: int = 1  # 页数
-    rows: List[Any] = []
+    rows = []
